MCauseInterrupt

Enum MCauseInterrupt 

#[repr(u32)]
pub enum MCauseInterrupt { UserSoftware = 0, SupervisorSoftware = 1, MachineSoftware = 3, UserTimer = 4, SupervisorTimer = 5, MachineTimer = 7, UserExternal = 8, SupervisorExternal = 9, MachineExternal = 11, }
Machine interrupt causes (mcause[XLEN‑1] = 1)

Variants



UserSoftware = 0

User software interrupt



SupervisorSoftware = 1

Supervisor software interrupt



MachineSoftware = 3

Machine software interrupt



UserTimer = 4

User timer interrupt



SupervisorTimer = 5

Supervisor timer interrupt



MachineTimer = 7

Machine timer interrupt



UserExternal = 8

User external interrupt



SupervisorExternal = 9

Supervisor external interrupt



MachineExternal = 11

Machine external interrupt

Implementations

Source

impl MCauseInterrupt

pub const fn from_code(code: u64) -> Option<Self>

Try to match an interrupt code to an MInterrupt (returns None for reserved/unknown codes)

pub const fn to_raw<Reg>(self) -> Reg::Type
where Reg: Register,

Convert this interrupt to its full raw mcause CSR value