MCauseException

Enum MCauseException 

#[repr(u32)]
pub enum MCauseException {
Show 14 variants InstructionAddressMisaligned = 0, InstructionAccessFault = 1, IllegalInstruction = 2, Breakpoint = 3, LoadAddressMisaligned = 4, LoadAccessFault = 5, StoreAddressMisaligned = 6, StoreAccessFault = 7, UserEnvironmentCall = 8, SupervisorEnvironmentCall = 9, MachineEnvironmentCall = 11, InstructionPageFault = 12, LoadPageFault = 13, StorePageFault = 15,
}
Machine exception causes (mcause[XLEN‑1] = 0)

Variants



InstructionAddressMisaligned = 0

Instruction address misaligned



InstructionAccessFault = 1

Instruction access fault



IllegalInstruction = 2

Illegal instruction



Breakpoint = 3

Breakpoint



LoadAddressMisaligned = 4

Load address misaligned



LoadAccessFault = 5

Load access fault



StoreAddressMisaligned = 6

Store/AMO address misaligned



StoreAccessFault = 7

Store/AMO access fault



UserEnvironmentCall = 8

Environment call from U-mode



SupervisorEnvironmentCall = 9

Environment call from S-mode



MachineEnvironmentCall = 11

Environment call from M-mode



InstructionPageFault = 12

Instruction page fault



LoadPageFault = 13

Load page fault



StorePageFault = 15

Store/AMO page fault

Implementations

Source

impl MCauseException

pub const fn from_code(code: u64) -> Option<Self>

Try to match an exception code to an MCauseException (returns None for reserved/unknown codes)

pub const fn to_raw<Reg>(self) -> Reg::Type
where Reg: Register,

Convert this exception to its full raw mcause CSR value